summaryrefslogtreecommitdiff
path: root/gpsdclient.h
diff options
context:
space:
mode:
authorGary E. Miller <gem@rellim.com>2019-02-22 18:17:57 -0800
committerGary E. Miller <gem@rellim.com>2019-02-22 18:17:57 -0800
commit59935603ccb54f12758672f2c077109523aeeaa7 (patch)
tree1f32c0ccf61986344e4fffa007c2873fcb9c6d8d /gpsdclient.h
parentae2ebe25de183ddd576615fa80682d6d6a5b0ffe (diff)
downloadgpsd-59935603ccb54f12758672f2c077109523aeeaa7.tar.gz
deg_to_str2(): Add new function. Thread safe, handles suffix.
Diffstat (limited to 'gpsdclient.h')
-rw-r--r--gpsdclient.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/gpsdclient.h b/gpsdclient.h
index e4e5dae2..e1066611 100644
--- a/gpsdclient.h
+++ b/gpsdclient.h
@@ -34,8 +34,11 @@ enum unit gpsd_units(void);
enum deg_str_type { deg_dd, deg_ddmm, deg_ddmmss };
float true2magnetic(double, double, double);
/* Warning: not thread safe */
extern char *deg_to_str(enum deg_str_type type, double f);
+extern char *deg_to_str2(enum deg_str_type type, double f,
+ char *buf, unsigned int buf_size,
+ const char *suffix_pos, const char *suffix_neg);
extern void gpsd_source_spec(const char *fromstring,
struct fixsource_t *source);
@@ -34,8 +34,11 @@ enum unit gpsd_units(void);
enum deg_str_type { deg_dd, deg_ddmm, deg_ddmmss };
float true2magnetic(double, double, double);
-/* Warning: not thread safe */
+/* Warning: deg_to_str() not thread safe */
extern char *deg_to_str(enum deg_str_type type, double f);